@@ -19,6 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+import glob
 import grp
 import gzip
 import io
@@ -1348,7 +1349,7 @@ class Install(install_misc.InstallBase):
                     apps_dir = 'usr/share/applications'
                     for desktop_file in (
                             apps_dir + '/oem-config-prepare-gtk.desktop',
-                            apps_dir + '/kde4/oem-config-prepare-kde.desktop'):
+                            apps_dir + '/kde/oem-config-prepare-kde.desktop'):
                         if os.path.exists(self.target_file(desktop_file)):
                             desktop_base = os.path.basename(desktop_file)
                             install_misc.chrex(
@@ -1649,6 +1650,18 @@ class Install(install_misc.InstallBase):
 
                 shutil.copy(source_network, target_network)
 
+        source_netplan = "/etc/netplan"
+        target_netplan = "/target" + source_netplan
+        if os.path.exists(source_netplan) and os.path.exists(target_netplan):
+            for cfg in glob.glob("90-NM-*", root_dir=source_netplan):
+                source_cfg = os.path.join(source_netplan, cfg)
+                target_cfg = os.path.join(target_netplan, cfg)
+
+                if os.path.exists(target_cfg):
+                    continue
+
+                shutil.copy(source_cfg, target_cfg)
+
     def copy_bluetooth_config(self):
         if 'UBIQUITY_OEM_USER_CONFIG' in os.environ:
             return
