@@ -30,7 +30,6 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <libindicator/indicator-ng.h>
-#include <libido/libido.h>
 
 #define ENTRY_DATA_NAME "indicator-custom-entry-data"
 
@@ -286,12 +285,18 @@ on_draw(GtkWidget *widget, cairo_t *cr, gpointer userdata) {
 	if (!pixbuf) {
 		pixbuf = gdk_pixbuf_new_from_file("/usr/share/lxpanel/images/lubuntu-background.png", NULL);
 	}
+	if (!pixbuf) {
+		pixbuf = gdk_pixbuf_new_from_file("/usr/share/themes/Greybird/ubiquity-panel-bg.png", NULL);
+	}
+	if (!pixbuf) {
+		pixbuf = gdk_pixbuf_new_from_file("/usr/share/budgie-desktop/ubiquity-panel-bg.png", NULL);
+	}
 	if (!pixbuf) {
 		pixbuf = gdk_pixbuf_new_from_file("/usr/share/ubiquity/pixmaps/panel.png", NULL);
 	}
 	if (pixbuf) {
 		gdk_cairo_set_source_pixbuf(cr, pixbuf, 0, 0);
-		cairo_pattern_set_extend(cairo_get_source(cr), CAIRO_EXTEND_REPEAT);
+		cairo_pattern_set_extend(cairo_get_source(cr), CAIRO_EXTEND_PAD);
 		cairo_paint(cr);
 		g_object_unref(pixbuf);
 	} else {
@@ -317,7 +322,6 @@ main(int argc, char* argv[]) {
 	/* Disable global menus */
 	g_unsetenv ("UBUNTU_MENUPROXY");
 	gtk_init(&argc, &argv);
-	ido_init ();
 	screen = gdk_screen_get_default();
 	win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_default_size (GTK_WINDOW (win), -1, 28);
