@@ -18,10 +18,8 @@
 
 # Update the installer from the network.
 
-from __future__ import print_function
-
-import sys
 import os
+import sys
 import syslog
 
 import apt
@@ -29,6 +27,7 @@ import apt_pkg
 
 from ubiquity import misc
 
+
 MAGIC_MARKER = "/var/run/ubiquity.updated"
 # Make sure that ubiquity is last, otherwise apt may try to install another
 # frontend.
@@ -66,8 +65,10 @@ class AcquireProgressDebconfProgressAdapter(apt.progress.base.AcquireProgress):
         apt.progress.base.AcquireProgress.pulse(self, owner)
         if self.current_cps > 0:
             info = self.frontend.get_string('apt_progress_cps')
-            info = info.replace(
-                '${SPEED}', apt_pkg.size_to_str(self.current_cps))
+            current_cps = apt_pkg.size_to_str(self.current_cps)
+            if isinstance(current_cps, bytes):
+                current_cps = current_cps.decode()
+            info = info.replace('${SPEED}', current_cps)
         else:
             info = self.frontend.get_string('apt_progress')
         info = info.replace('${INDEX}', str(self.current_items))
