@@ -31,6 +31,8 @@
 import math
 
 import cairo
+import gi
+gi.require_version('PangoCairo', '1.0')
 from gi.repository import GObject, Gdk, Gtk, PangoCairo
 
 from ubiquity.misc import find_in_os_prober, format_size
@@ -163,7 +165,7 @@ class CairoExtensions:
         r, g, b = color[:2], color[2:4], color[4:]
         r, g, b = [(int(n, 16) / 255.0) for n in (r, g, b)]
         return Color(r, g, b)
-        #return CairoExtensions.rgba_to_color((color << 8) | 0x000000ff)
+        # return CairoExtensions.rgba_to_color((color << 8) | 0x000000ff)
 
     @staticmethod
     def rounded_rectangle(cr, x, y, w, h, r, corners=CairoCorners.all,
@@ -529,4 +531,5 @@ class SegmentedBar(Gtk.DrawingArea):
             else:
                 self.subtitle = ''
 
+
 GObject.type_register(SegmentedBar)
